package com.persagy.apm.alarmservice.dependency.rwd.client;

import java.util.List;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.cloud.openfeign.SpringQueryMap;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import com.alibaba.fastjson.JSONObject;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.persagy.apm.alarmservice.common.constants.FeignClientNameConstants;
import com.persagy.apm.alarmservice.dependency.rwd.client.fallback.DmpRwdClientFallbackFactory;
import com.persagy.apm.dmpalarm.criteria.JsonCriteria;
import com.persagy.apm.dmpalarm.web.PagedResponse;
import com.persagy.apm.energyalarmstarter.alarmdata.feign.DmpResult;
import com.persagy.apm.energyalarmstarter.alarmdata.model.dto.common.UrlParamDTO;

import feign.Headers;

/**
 * 物理世界feign客户端
 *
 * @author lixing
 * @version V1.0 2021/3/22 2:13 下午
 **/
@FeignClient(name = FeignClientNameConstants.DMP_RWD, url="${dmp_rwd.url}" ,fallbackFactory = DmpRwdClientFallbackFactory.class)
public interface DmpRwdClient {

    /**
     * 查询物理世界的对象
     *
     * @param urlParamDTO request params
     * @param jsonObject request body
     * @return 对象列表
     * @author lixing
     * @version V1.0 2021/5/19 3:36 下午
     */
    @PostMapping("/rwd/instance/object/query")
    @Headers({"Content-Type: application/json"})
    DmpResult<List<JSONObject>> objQuery(
            @SpringQueryMap UrlParamDTO urlParamDTO,  @RequestBody JSONObject jsonObject);
    

    @PostMapping("rwd/instance/object/query")
    public PagedResponse<ObjectNode> queryObj(
            @RequestParam("projectId") String projectId,
            @RequestParam("groupCode") String groupCode,
            @RequestBody JsonCriteria criteria);
}
